# State MoSeq 

State MoSeq (sMoSeq) is a method for discovering high-level states states in animal behavior. Given low-level behavior labels (e.g. MoSeq syllables), sMoSeq fits a hierarchical hidden Markov model to identify how behaviors are clustered over time. For additional details, see the [TODO: add paper link].


## [Documentation](https://state-moseq.readthedocs.io/en/latest/)

- TODO: Colab

- [Installation](https://state-moseq.readthedocs.io/en/latest/install.html)

- [Tutorial](https://state-moseq.readthedocs.io/en/latest/modeling.html)



# License
sMoSeq is freely available for academic use under a license provided by Harvard University. Please refer to the license file for details. If you are interested in using sMoSeq for commercial purposes please contact Bob Datta directly at srdatta@hms.harvard.edu, who will put you in touch with the appropriate people in the Harvard Technology Transfer office.

